Token class
Properties
- coturnIp → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String
-
no setter
- role → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
no setter
- token → String
-
no setter
- turnCredential → String
-
no setter
- turnUsername → String
-
no setter
- url → String
-
final
- version → String
-
no setter
Methods
-
appendInfo(
{String? role, String? coturnIp, String? turnUsername, String? turnCredential}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited